/// <reference types="node" />
/// <reference types="node" />
import { ChildProcess } from 'child_process';
export interface LambdaProcess extends ChildProcess {
    arn?: string;
    _msgId: number;
    invoke(event: any, context: any, callback: (err: Error | null, result?: any) => void): void;
}
export interface SpawnLambdaOptions {
    /**
     * If this option is truthy, `ts-node` is used to launch a lambda process.
     */
    typescript?: boolean;
    /**
     * An ARN that identify a lambda process.
     */
    arn?: string;
    /**
     * A current directory of the lambda process. (Default: `process.cwd()`)
     */
    dir?: string;
    /**
     * Names of a module and a function. (Default: `index.handler`)
     */
    handler?: string;
    command?: string;
    args?: string[];
    /**
     * An object of environment variables that is used to launch a lambda process. (Default: `process.env`)
     */
    env?: NodeJS.ProcessEnv;
    /**
     * An object of environment variables that is used as the lambda configuration.
     * This object is merged to `env`.
     */
    lambdaEnv?: NodeJS.ProcessEnv;
    additionalNodePath?: string;
    stdio?: any;
    /**
     * A path of a directory that the lambda function is located.
     */
    moduleDir?: string;
    project?: string;
}
export declare function spawnLambda(options: SpawnLambdaOptions): LambdaProcess;
